==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebColumnMovingEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingEndEventArgsDetailDescriptionMetadata } from "./WebColumnMovingEndEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEndEventArgsDescription } from "./WebColumnMovingEndEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnMovingEndEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingEndEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingEndEventArgsDescriptionMetadata.a == null) {
                WebColumnMovingEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingEndEventArgsDescriptionMetadata.c(WebColumnMovingEndEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebColumnMovingEndEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnMovingEndEventArgsDescriptionMetadata.a);
            WebColumnMovingEndEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnMovingEndEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebColumnMovingEndEventArgsDetail");
        }
        static d(a) {
            WebColumnMovingEndEventArgsDescriptionMetadata.b(a);
            a.aa("WebColumnMovingEndEventArgs", () => new WebColumnMovingEndEventArgsDescription());
            a.z("WebColumnMovingEndEventArgs", WebColumnMovingEndEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnMovingEndEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnMovingEndEventArgsDescriptionMetadata, 'WebColumnMovingEndEventArgsDescriptionMetadata');
    WebColumnMovingEndEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingEndEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnMovingEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingEndEventArgsDetailDescriptionMetadata } from "./WebColumnMovingEndEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEndEventArgsDescription } from "./WebColumnMovingEndEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnMovingEndEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingEndEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingEndEventArgsDescriptionMetadata.a == null) {
                WebColumnMovingEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingEndEventArgsDescriptionMetadata.c(WebColumnMovingEndEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnMovingEndEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnMovingEndEventArgsDescriptionMetadata.a);
            WebColumnMovingEndEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnMovingEndEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnMovingEndEventArgsDetail");
        }
        static d(a) {
            WebColumnMovingEndEventArgsDescriptionMetadata.b(a);
            a.ac("WebColumnMovingEndEventArgs", () => new WebColumnMovingEndEventArgsDescription());
            a.ab("WebColumnMovingEndEventArgs", WebColumnMovingEndEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnMovingEndEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnMovingEndEventArgsDescriptionMetadata, 'WebColumnMovingEndEventArgsDescriptionMetadata');
    WebColumnMovingEndEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingEndEventArgsDescriptionMetadata;
})();
